GetQueryResultsFluentBuilder

Struct GetQueryResultsFluentBuilder 

pub struct GetQueryResultsFluentBuilder { /* private fields */ }
Fluent builder constructing a request to GetQueryResults.

Streams the results of a single query execution specified by QueryExecutionId from the Athena query results location in Amazon S3. For more information, see Working with query results, recent queries, and output files in the Amazon Athena User Guide. This request does not execute the query but returns results. Use StartQueryExecution to run a query.

To stream query results successfully, the IAM principal with permission to call GetQueryResults also must have permissions to the Amazon S3 GetObject action for the Athena query results location.

IAM principals with permission to the Amazon S3 GetObject action for the query results location are able to retrieve query results from Amazon S3 even if permission to the GetQueryResults action is denied. To restrict user or role access, ensure that Amazon S3 permissions to the Athena query location are denied.

Implementations

Source

impl GetQueryResultsFluentBuilder

pub fn as_input(&self) -> &GetQueryResultsInputBuilder

Access the GetQueryResults as a reference.

pub async fn send( self, ) -> Result<GetQueryResultsOutput, SdkError<GetQueryResultsError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<GetQueryResultsOutput, GetQueryResultsError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn into_paginator(self) -> GetQueryResultsPaginator

Create a paginator for this request

Paginators are used by calling send().await which returns a PaginationStream.

pub fn query_execution_id(self, input: impl Into<String>) -> Self

The unique ID of the query execution.

pub fn set_query_execution_id(self, input: Option<String>) -> Self

The unique ID of the query execution.

pub fn get_query_execution_id(&self) -> &Option<String>

The unique ID of the query execution.

pub fn next_token(self, input: impl Into<String>) -> Self

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.

pub fn set_next_token(self, input: Option<String>) -> Self

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.

pub fn get_next_token(&self) -> &Option<String>

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.

pub fn max_results(self, input: i32) -> Self

The maximum number of results (rows) to return in this request.

pub fn set_max_results(self, input: Option<i32>) -> Self

The maximum number of results (rows) to return in this request.

pub fn get_max_results(&self) -> &Option<i32>

The maximum number of results (rows) to return in this request.

pub fn query_result_type(self, input: QueryResultType) -> Self

When you set this to DATA_ROWS or empty, GetQueryResults returns the query results in rows. If set to DATA_MANIFEST, it returns the manifest file in rows. Only the query types CREATE TABLE AS SELECT, UNLOAD, and INSERT can generate a manifest file. If you use DATA_MANIFEST for other query types, the query will fail.

pub fn set_query_result_type(self, input: Option<QueryResultType>) -> Self

When you set this to DATA_ROWS or empty, GetQueryResults returns the query results in rows. If set to DATA_MANIFEST, it returns the manifest file in rows. Only the query types CREATE TABLE AS SELECT, UNLOAD, and INSERT can generate a manifest file. If you use DATA_MANIFEST for other query types, the query will fail.

pub fn get_query_result_type(&self) -> &Option<QueryResultType>

When you set this to DATA_ROWS or empty, GetQueryResults returns the query results in rows. If set to DATA_MANIFEST, it returns the manifest file in rows. Only the query types CREATE TABLE AS SELECT, UNLOAD, and INSERT can generate a manifest file. If you use DATA_MANIFEST for other query types, the query will fail.