#[non_exhaustive]pub struct GetQueryResultsInputBuilder { /* private fields */ }Expand description
A builder for GetQueryResultsInput.
Implementations
Sourceimpl GetQueryResultsInputBuilder
impl GetQueryResultsInputBuilder
Sourcepub fn query_execution_id(self, input: impl Into<String>) -> Self
pub fn query_execution_id(self, input: impl Into<String>) -> Self
The unique ID of the query execution.
This field is required.Sourcepub fn set_query_execution_id(self, input: Option<String>) -> Self
pub fn set_query_execution_id(self, input: Option<String>) -> Self
The unique ID of the query execution.
Sourcepub fn get_query_execution_id(&self) -> &Option<String>
pub fn get_query_execution_id(&self) -> &Option<String>
The unique ID of the query execution.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results (rows) to return in this request.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results (rows) to return in this request.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results (rows) to return in this request.
Sourcepub fn query_result_type(self, input: QueryResultType) -> Self
pub fn query_result_type(self, input: QueryResultType) -> Self
When you set this to DATA_ROWS or empty, GetQueryResults returns the query results in rows. If set to DATA_MANIFEST, it returns the manifest file in rows. Only the query types CREATE TABLE AS SELECT, UNLOAD, and INSERT can generate a manifest file. If you use DATA_MANIFEST for other query types, the query will fail.
Sourcepub fn set_query_result_type(self, input: Option<QueryResultType>) -> Self
pub fn set_query_result_type(self, input: Option<QueryResultType>) -> Self
When you set this to DATA_ROWS or empty, GetQueryResults returns the query results in rows. If set to DATA_MANIFEST, it returns the manifest file in rows. Only the query types CREATE TABLE AS SELECT, UNLOAD, and INSERT can generate a manifest file. If you use DATA_MANIFEST for other query types, the query will fail.
Sourcepub fn get_query_result_type(&self) -> &Option<QueryResultType>
pub fn get_query_result_type(&self) -> &Option<QueryResultType>
When you set this to DATA_ROWS or empty, GetQueryResults returns the query results in rows. If set to DATA_MANIFEST, it returns the manifest file in rows. Only the query types CREATE TABLE AS SELECT, UNLOAD, and INSERT can generate a manifest file. If you use DATA_MANIFEST for other query types, the query will fail.
Sourcepub fn build(self) -> Result<GetQueryResultsInput, BuildError>
pub fn build(self) -> Result<GetQueryResultsInput, BuildError>
Consumes the builder and constructs a GetQueryResultsInput.
Sourceimpl GetQueryResultsInputBuilder
impl GetQueryResultsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetQueryResultsOutput, SdkError<GetQueryResultsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetQueryResultsOutput, SdkError<GetQueryResultsError, HttpResponse>>
Sends a request with this input using the given client.