#[non_exhaustive]pub struct GetQueryResultsOutputBuilder { /* private fields */ }Expand description
A builder for GetQueryResultsOutput.
Implementations
Sourceimpl GetQueryResultsOutputBuilder
impl GetQueryResultsOutputBuilder
Sourcepub fn update_count(self, input: i64) -> Self
pub fn update_count(self, input: i64) -> Self
The number of rows inserted with a CREATE TABLE AS SELECT, INSERT INTO, or UPDATE statement.
Sourcepub fn set_update_count(self, input: Option<i64>) -> Self
pub fn set_update_count(self, input: Option<i64>) -> Self
The number of rows inserted with a CREATE TABLE AS SELECT, INSERT INTO, or UPDATE statement.
Sourcepub fn get_update_count(&self) -> &Option<i64>
pub fn get_update_count(&self) -> &Option<i64>
The number of rows inserted with a CREATE TABLE AS SELECT, INSERT INTO, or UPDATE statement.
Sourcepub fn result_set(self, input: ResultSet) -> Self
pub fn result_set(self, input: ResultSet) -> Self
The results of the query execution.
Sourcepub fn set_result_set(self, input: Option<ResultSet>) -> Self
pub fn set_result_set(self, input: Option<ResultSet>) -> Self
The results of the query execution.
Sourcepub fn get_result_set(&self) -> &Option<ResultSet>
pub fn get_result_set(&self) -> &Option<ResultSet>
The results of the query execution.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn build(self) -> GetQueryResultsOutput
pub fn build(self) -> GetQueryResultsOutput
Consumes the builder and constructs a GetQueryResultsOutput.